============
Introduction
============

.. toctree::
  :maxdepth: 2


What is cellsino?
=================
Cellsino is a tool for generating in-silico fluorescence and refractive
index sinograms of predefined cell phantoms. The computation of the
sinogram data is done with semi-analytical approaches (e.g. Rytov approximation
for spheres :cite:`Mueller2018`) and is thus comparatively fast and
accurate.

